node-redis-operation
==========================

A node.js redis-operation for Redis.

## About
   node-redis-operation 是最高层操作redis的对象.它提供了redis中各种数据结构的操作。

## Usage
//redis实例初始化，并存储到app
var redis =new(require('redis-operation'))(app);

## Implemented methods
  * **stringSet**
```javascript
/**
 * 字符串set操作
 * eg:this.app.redisPool.stringSet(key,值,数据库分片,回调函数);
 * 其中回调函数第一个参数为错误信息，第二个参数为插入个数。
 */
stringSet(key, value, index, callBack)
```

```javascript
/**
 *  字符串Get操作
 *  eg:this.app.redisPool.stringGet(key,数据库分片,回调函数);
 * 其中回调函数第一个参数为错误信息，第二个参数为查询值。
 */
stringGet(key, index, callBack)
```

```javascript
/**
 * 字符串添加失效时间
 * eg:this.app.redisPool.stringExpire(key,超时时间（秒）, 数据库分片,回调函数);
 * 其中回调函数第一个参数为错误信息，第二个参数为起作用数据的条数。
 */
stringExpire(key, timeout, index, callBack)
```

```javascript
/**
 * 根据key删除字符串
 * eg:this.app.redisPool.stringDel(key, 数据库分片,回调函数);
 * 其中回调函数第一个参数为错误信息，第二个参数为起作用数据的条数。
 */
stringDel(key, index, callBack)
```

```javascript
/**
 * 插入数据到具体哈希表
 * eg:this.app.redis.hSet(key，哈希表内部key,值,数据库分片,回调函数);
 * 其中回调函数第一个参数为错误信息，第二个参数为起作用数据的条数。
 */
hSet(key, field, value, index, callBack) 
```

```javascript
/**
 * 获取一个哈希表中的一行数据
 * eg:this.app.redis.hGet(key，哈希表内部key,数据库分片,回调函数)
 * 其中回调函数第一个参数为错误信息，第二个参数为查询值。
 */
hGet(key, field, index, callBack)
```


```javascript
/**
 * 获取一个具体哈希表所有数据
 * eg:this.app.redis.hGetAll(key，数据库分片,回调函数)
 * 其中回调函数第一个参数为错误信息，第二个参数为查询值。
 */
hGetAll(key, index, callBack) 
```

```javascript
/**
 * 获取一个具体哈希表长度
 * eg:this.app.redis.hHength(key，数据库分片,回调函数)
 * 其中回调函数第一个参数为错误信息，第二个参数为查询值。
 */
hHength(key, index, callBack)
```

```javascript
/**
 * 批量删除哈希表数据，field为数组，如果为空，就删除该哈希表，如果有数据，删除数组中对应field的哈希数据
 * eg:this.app.redis.hDel(key，哈希表内部key数组，数据库分片,回调函数)
 * 其中回调函数第一个参数为错误信息，第二个参数为起作用数据的条数。
 */
hDel(key, fields, index, callBack)
```


```javascript
/**
 * 队列插入，按插入先后次序顺序排列（第一行，放第一个插入的）
 * eg:this.app.redis.queueRpush(key, 值，数据库分片,回调函数)
 * 回调函数第一个参数为错误信息，第二个参数为插入数据位于该列表的索引值。
 */
queueRpush(key, value, index, callBack)
```


```javascript
/**
 * 队列插入，按插入先后次序倒叙排列（第一行，放最后一个插入的）
 * eg:this.app.redis.queueLpush(key, 值，数据库分片,回调函数)
 *回调函数第一个参数为错误信息，第二个参数为插入数据位于该列表的索引值。
 */
queueLpush(key, value, index, callBack) 
```

```javascript
/**
 * 出队列，从队列右边开始
 * eg:this.app.redis.queueRpop(key, 值，数据库分片,回调函数)
 * 其中回调函数第一个参数为错误信息，第二个参数为查询值。
 */
queueRpop(key, index, callBack)
```


```javascript
/**
 * 出队列，从队列左边开始
 * eg:this.app.redis.queueLpop(key, 值，数据库分片,回调函数)
 * 其中回调函数第一个参数为错误信息，第二个参数为查询值。
 */
queueLpop(key, index, callBack)
```

```javascript
/**
 *获取列表指定范围内的元素 
 *eg:redis.queueLrange("newlogin",0,5,1,function(error,replay){console.log(replay);});
 *其中回调函数第一个参数为错误信息，第二个参数为查询值。
 */
queueLrange(key,start,end,index,callBack) 
```

```javascript
/**
 * 获取列表长度
 * eg:redis.queueLlen("newlogin",1,function(error,replay){console.log(replay);});
 * 其中回调函数第一个参数为错误信息，第二个参数为查询值。
 */
queueLlen(key,index,callBack) 
```



